<!DOCTYPE TS><TS>
<defaultcodec>iso8859-1</defaultcodec>
<context>
    <name>AddLnk</name>
    <message>
        <source>Add a &quot;Catalog Link&quot; to the database</source>
        <translation>Dodaj &quot;Łącze do katalogu&quot; do bazy danych</translation>
    </message>
    <message>
        <source>Location of the .hcf file:</source>
        <translation>Polozenie pliku .hcf:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>CdCat databases (*.hcf )</source>
        <translation>Bazy danych CdCat&apos;a (*.hcf)</translation>
    </message>
    <message>
        <source>Open a file...</source>
        <translation>Otworz plik...</translation>
    </message>
</context>
<context>
    <name>CdCatConfig</name>
    <message>
        <source>Error during autoload...</source>
        <translation>Błąd podczas automatycznego ładowania...</translation>
    </message>
    <message>
        <source>I can&apos;t open the autoload catalog.
Check the file, or change the autoload option in the config dialog!
</source>
        <translation>Nie mogę otworzyć automatycznie ładowanego spisu.
Sprawdź plik, albo zmień ustawienia opcji automatycznego ładowania plku w Ustawieniach!
</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Error during write config...</source>
        <translation type="obsolete">Błąd podczas zapisywania pliku konfiguracyjnego...</translation>
    </message>
    <message>
        <source>I can&apos;t get the HOME environment variable.
It is necessary couse I&apos;d like to save the config file into your home directory.</source>
        <translation type="obsolete">Nie mogę odnaleść zmiennej środowiskowej $HOME.
Jest potrzebna, gdyż chciałem zapisać ustawienia do twojego katalogu domowego.</translation>
    </message>
    <message>
        <source>I can&apos;t create or rewrite the ./cdcat.cfg                      </source>
        <translation type="obsolete">Nie mogę utworzyć albo nadpisać pliku ./cdcat.cfg</translation>
    </message>
    <message>
        <source>I can&apos;t create or rewrite the $(HOME)/.cdcatconfig                      </source>
        <translation type="obsolete">Nie mogę utworzyć albo nadpisać $(HOME)/.cdcatconfig</translation>
    </message>
    <message>
        <source>I can&apos;t open the autoload catalog according the first command line parameter.
Check the file!
</source>
        <translation>Nie mogę otworzyć spisu podanego w linii poleceń.
Sprawdz nazwe pliku!</translation>
    </message>
    <message>
        <source>I can&apos;t get the $HOME environment variable.
It is necessary couse I&apos;d like to save the config file into your home directory.</source>
        <translation>Nie mogę odnaleść zmiennej środowiskowej $HOME.
Jest potrzebna, gdyż chciałem zapisać ustawienia do twojego katalogu domowego.</translation>
    </message>
    <message>
        <source>I can&apos;t create or rewrite the ./cdcat.cfg file </source>
        <translation>Nie mogę utworzyć albo nadpisać pliku ./cdcat.cfg</translation>
    </message>
    <message>
        <source>I can&apos;t create or rewrite the $(HOME)/.cdcatconfig file </source>
        <translation>Nie mogę utworzyć albo nadpisać $(HOME)/.cdcatconfig</translation>
    </message>
    <message>
        <source>Error while saving config file...</source>
        <translation>Błąd podczas zapisywania pliku konfiguracyjnego...</translation>
    </message>
</context>
<context>
    <name>CdCatMainWidget</name>
    <message>
        <source>No selected item</source>
        <translation type="obsolete">Brak zaznaczonych obiektów</translation>
    </message>
    <message>
        <source>Directory Tree</source>
        <translation>Drzewo katalogów</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <source>New...</source>
        <translation>Nowy...</translation>
    </message>
    <message>
        <source>Open...</source>
        <translation>Otwórz...</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation>Zapisz jako...</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Wyjdz</translation>
    </message>
    <message>
        <source>Add media...</source>
        <translation>Dodaj nośnik...</translation>
    </message>
    <message>
        <source>Rescan media...</source>
        <translation>Skanuj ponownie nośnik...</translation>
    </message>
    <message>
        <source>Insert Catalog...</source>
        <translation>Wstaw Spis...</translation>
    </message>
    <message>
        <source>Rename node...</source>
        <translation>Zmien nazwe wpisu...</translation>
    </message>
    <message>
        <source>Delete node</source>
        <translation>Skasuj wpis</translation>
    </message>
    <message>
        <source>Sort media by number</source>
        <translation>Sortuj nośniki wg. numerów</translation>
    </message>
    <message>
        <source>Sort media by name</source>
        <translation>Sortuj nośniki wg. nazw</translation>
    </message>
    <message>
        <source>Sort media by type</source>
        <translation>Sortuj nośniki wg. typów</translation>
    </message>
    <message>
        <source>Sort media by time</source>
        <translation>Sortuj nośniki wg. dat</translation>
    </message>
    <message>
        <source>Seek in database...</source>
        <translation>Szukaj w bazie danych...</translation>
    </message>
    <message>
        <source>Node size</source>
        <translation>Rozmiar wpisu</translation>
    </message>
    <message>
        <source>Configuration...</source>
        <translation>Konfiguracja...</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O...</translation>
    </message>
    <message>
        <source>Catalog</source>
        <translation>Spis</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edytuj</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Inne</translation>
    </message>
    <message>
        <source>Hyper&apos;s CD Catalogizer</source>
        <translation>Katalog CD Hyper&apos;a</translation>
    </message>
    <message>
        <source>Open a catalog from a file.</source>
        <translation>Otworz spis z pliku.</translation>
    </message>
    <message>
        <source>Save all modification to the disc.</source>
        <translation type="obsolete">Zapisz wszystkie zmiany na dysk.</translation>
    </message>
    <message>
        <source>Save the full catalog to file.</source>
        <translation type="obsolete">Zapisz cały spis na dysk.</translation>
    </message>
    <message>
        <source>Close the actual catalog.</source>
        <translation>Zamknij otwarty spis.</translation>
    </message>
    <message>
        <source>Add a new media to the catalog.</source>
        <translation>Dodaj nowy nośnik do spisu.</translation>
    </message>
    <message>
        <source>Rescan the selected media from the disk.</source>
        <translation type="obsolete">Odczytaj ponownie wybrany nośnik.</translation>
    </message>
    <message>
        <source>Delete the selected media from the catalog.</source>
        <translation>Skasuj wybrany nośnik ze spisu.</translation>
    </message>
    <message>
        <source>Configuration of the program.</source>
        <translation>Konfiguracja programu.</translation>
    </message>
    <message>
        <source>Create a new, empty catalog and close the previous.</source>
        <translation>Utwórz nowy, pusty spis i zamknij otwarty obecnie.</translation>
    </message>
    <message>
        <source>Search an element in the database(catalog).You can search filenames, directory names, name parts or mp3 tags etc...</source>
        <translation>Szukaj w spisie. Możesz szukać wg. nazw plików, katalogów, tagów ID3, itp...</translation>
    </message>
    <message>
        <source>Search an element.</source>
        <translation>Szukaj w spisie.</translation>
    </message>
    <message>
        <source>Import from csv</source>
        <translation type="obsolete">Import z CSV</translation>
    </message>
    <message>
        <source>Recent files...</source>
        <translation>Ostatnio otwierane pliki...</translation>
    </message>
    <message>
        <source>Export database</source>
        <translation>Eksportuj baze danych</translation>
    </message>
    <message>
        <source>Import/Export</source>
        <translation>Import/Export</translation>
    </message>
    <message>
        <source>Re-Number media node...</source>
        <translation>Zmień numer nosnika...</translation>
    </message>
    <message>
        <source>Import database (csv/gtktalog)</source>
        <translation>Importuj baze danych (csv/gtktalog)</translation>
    </message>
    <message>
        <source>Borrowing info...</source>
        <translation>Pożyczanie...</translation>
    </message>
    <message>
        <source>Save all modifications to the disc.</source>
        <translation>Zapisz wszystkie zmiany na dysk.</translation>
    </message>
    <message>
        <source>Save the catalog to a new file.</source>
        <translation>Zapisz katalog do nowego pliku.</translation>
    </message>
    <message>
        <source>Add a link to a CdCAt Catalog...</source>
        <translation>Dodaj łącze do katalogu CdCat&apos;a...</translation>
    </message>
    <message>
        <source>Set Colors...</source>
        <translation>Ustaw kolory...</translation>
    </message>
    <message>
        <source>No item selected</source>
        <translation>Niewybrano żadnego elementu</translation>
    </message>
    <message>
        <source>Rescan the selected media.</source>
        <translation>Skanuj ponownie wybrany nośnik.</translation>
    </message>
    <message>
        <source>Seek in the panel</source>
        <translation>Szukaj w panelu</translation>
    </message>
</context>
<context>
    <name>ColorSchemePreview</name>
    <message>
        <source>Title:</source>
        <translation>Tytuł:</translation>
    </message>
    <message>
        <source>Road To Hell</source>
        <translation>Road To Hell</translation>
    </message>
</context>
<context>
    <name>ColorSettings</name>
    <message>
        <source>ColorSettings</source>
        <translation>UstawieniaKoloru</translation>
    </message>
    <message>
        <source>Comment area background and the file higlighting line</source>
        <translation>Tło okna z komentarzem oraz podświetlenie linia zaznaczenia</translation>
    </message>
    <message>
        <source>Frame of comment area</source>
        <translation>Ramka okna z komentarzem</translation>
    </message>
    <message>
        <source>Comment window static text (Program text)</source>
        <translation>Stały tekst komentarza (Tekst z programu)</translation>
    </message>
    <message>
        <source>Comment window variable text (Data)</source>
        <translation>Zmienny tekst komentarza (Dane)</translation>
    </message>
    <message>
        <source>color</source>
        <translation>kolor</translation>
    </message>
    <message>
        <source>Red:</source>
        <translation>Czerwony:</translation>
    </message>
    <message>
        <source>Green:</source>
        <translation>Zielony:</translation>
    </message>
    <message>
        <source>Blue:</source>
        <translation>Niebieski:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
</context>
<context>
    <name>CommentWidget</name>
    <message>
        <source>Edit and refresh the actual comment page.</source>
        <translation>Edytuj i odświerz strone z komentarzami.</translation>
    </message>
    <message>
        <source>Upper container! (..)</source>
        <translation>Wyższy katalog! (..)</translation>
    </message>
    <message>
        <source>name:</source>
        <translation type="obsolete">Nazwa:</translation>
    </message>
    <message>
        <source>type:</source>
        <translation type="obsolete">Typ:</translation>
    </message>
    <message>
        <source> CdCat Catalog root</source>
        <translation>Katalog główny CdCat&apos;a</translation>
    </message>
    <message>
        <source> Directory</source>
        <translation>Katalog</translation>
    </message>
    <message>
        <source> File</source>
        <translation>Plik</translation>
    </message>
    <message>
        <source>Media</source>
        <translation>Nośnik</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Rozmiar:</translation>
    </message>
    <message>
        <source>Last moification:</source>
        <translation type="obsolete">Ostatnia zmiana:</translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation>Właściciel:</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Nieznane</translation>
    </message>
    <message>
        <source>Media (number/name):</source>
        <translation>Nośnik (numer/nazwa):</translation>
    </message>
    <message>
        <source>Mp3-Tag:</source>
        <translation>MP3-Tag:</translation>
    </message>
    <message>
        <source>(Art/Tit/Alb/Year/Comm)</source>
        <translation>(Art/Tyt/Alb/Rok/Kom)</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Komentarz:</translation>
    </message>
    <message>
        <source>Shows the content of the file.</source>
        <translation>Pokazuje zawartość pliku.</translation>
    </message>
    <message>
        <source>There is not selected element.</source>
        <translation type="obsolete">Nie ma wybranego elementu.</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nazwa:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>There is no selected element.</source>
        <translation>Nie ma wybranego elementu.</translation>
    </message>
    <message>
        <source> Link to a CdCat catalog</source>
        <translation>Łącze do katalogu CdCat&apos;a</translation>
    </message>
    <message>
        <source>Location:</source>
        <translation>Położenie:</translation>
    </message>
    <message>
        <source>Last modification:</source>
        <translation>Ostania zmiana:</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <source>Configure  CdCat...</source>
        <translation>Konfiguruj CdCat...</translation>
    </message>
    <message>
        <source>Autoload DataBase on startup</source>
        <translation>Automatyczne ładowanie Bazy danych na starcie</translation>
    </message>
    <message>
        <source>Save the XML-db.file nicer format(needs more space)</source>
        <translation>Zapisz do przejzystrzego formatu XML-db. (wymaga więcej mijesca)</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Application font size.(must restart cdcat!) </source>
        <translation>Wielkość czcionki w programie.(wymaga ponownego uruchomienia programu po zmianie!)</translation>
    </message>
    <message>
        <source>CdCat Databases (*.hcf)</source>
        <translation>Bazy danych CdCat&apos;a (*.hcf)</translation>
    </message>
    <message>
        <source>Choose a file to automatically load!</source>
        <translation type="obsolete">Wybierz plik do automatycznego ładowania!</translation>
    </message>
    <message>
        <source>Path to cdrom device</source>
        <translation>Ścieżka do napędu CD-ROM</translation>
    </message>
    <message>
        <source>Scanning: mount cdrom at start / eject when finish</source>
        <translation>Skanowanie: montuj CD-rom przed skanowaniem / wysuń po zakończeniu</translation>
    </message>
    <message>
        <source>Use own font size</source>
        <translation>Użyj własnego rozmiaru czcionki</translation>
    </message>
    <message>
        <source>Number of history entries</source>
        <translation>Liczba wpisów w historii</translation>
    </message>
    <message>
        <source>Choose path to cdrom!</source>
        <translation>Wybierz ścieżke do CD-ROMu!</translation>
    </message>
    <message>
        <source>The language of CdCat interface</source>
        <translation>Język interface&apos;u CdCat&apos;a</translation>
    </message>
    <message>
        <source>Select readable items</source>
        <translation type="obsolete">Wybierz odczywywane pliki</translation>
    </message>
    <message>
        <source>Choose a file to load automatically!</source>
        <translation>Wybierz plik do automatycznego ładowania!</translation>
    </message>
    <message>
        <source>Automatically save the database after every scan (for dafety sake)</source>
        <translation>Automatycznie zapisz baze danych po każdym skanowaniu (na wszelki wypadek)</translation>
    </message>
    <message>
        <source>Select additional items to read</source>
        <translation>Wybierz odczywywane pliki</translation>
    </message>
</context>
<context>
    <name>DataBase</name>
    <message>
        <source>I can&apos;t rewrite the file: %1</source>
        <translation>Nie mogę nadpisać pliku: %1</translation>
    </message>
    <message>
        <source>I can&apos;t create the file: %1</source>
        <translation>Nie mogę stworzyć pliku: %1</translation>
    </message>
    <message>
        <source>There is not opened database!</source>
        <translation type="obsolete">Nie ma otwarej bazy danych!</translation>
    </message>
    <message>
        <source>I can&apos;t open the file: %1</source>
        <translation>Nie mogę otworzyć pliku: %1</translation>
    </message>
    <message>
        <source>Cannot read directory: %1</source>
        <translation>Nie mogę odczytać spisu: %1</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Ignore directory</source>
        <translation>Ignoruj katalog</translation>
    </message>
    <message>
        <source>Cancel scanning</source>
        <translation>Anuluj skanowanie</translation>
    </message>
    <message>
        <source>Symbolic link#Points to:</source>
        <translation>Powiązanie symboliczne#Wskazuje na:</translation>
    </message>
    <message>
        <source>Error while parsing file: %1</source>
        <translation>Błąd podczas parsowania pliku: %1</translation>
    </message>
    <message>
        <source>No database opened!</source>
        <translation>Nie otwarto żadnej bazy danych!</translation>
    </message>
</context>
<context>
    <name>DirectoryView</name>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
</context>
<context>
    <name>GuiSlave</name>
    <message>
        <source>No opened database.</source>
        <translation type="obsolete">Brak otwartej bazy danych.</translation>
    </message>
    <message>
        <source>No selected item.</source>
        <translation type="obsolete">Brak zaznaczonych obiektów.</translation>
    </message>
    <message>
        <source>Directory</source>
        <translation>Katalog</translation>
    </message>
    <message>
        <source>Catalog</source>
        <translation>Spis</translation>
    </message>
    <message>
        <source>Unknown(DB)</source>
        <translation>Nieznany(DB)</translation>
    </message>
    <message>
        <source>CD</source>
        <translation>CD</translation>
    </message>
    <message>
        <source>DVD</source>
        <translation>DVD</translation>
    </message>
    <message>
        <source>HardDisc</source>
        <translation>Dysk Twardy</translation>
    </message>
    <message>
        <source>Floppy</source>
        <translation>Dyskietka</translation>
    </message>
    <message>
        <source>NetworkDrv</source>
        <translation>Napęd Sieciowy</translation>
    </message>
    <message>
        <source>FlashDrv</source>
        <translation>Napęd Flash</translation>
    </message>
    <message>
        <source>OtherDevice</source>
        <translation>Inne urządzenie</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Plik</translation>
    </message>
    <message>
        <source>Hyper&apos;s CD Catalogizer (modified)</source>
        <translation>Katalog CD Hyper&apos;a (zmienione)</translation>
    </message>
    <message>
        <source>Hyper&apos;s CD Catalogizer</source>
        <translation>Katalog CD Hyper&apos;a</translation>
    </message>
    <message>
        <source>CdCat databases (*.hcf )</source>
        <translation>Bazy danych CdCat&apos;a (*.hcf)</translation>
    </message>
    <message>
        <source>Open a file...</source>
        <translation>Otworz plik...</translation>
    </message>
    <message>
        <source>Error while opening...</source>
        <translation>Błąd podczas otwierania...</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Save to file...</source>
        <translation>Zapisz do pliku...</translation>
    </message>
    <message>
        <source>Error while saving...</source>
        <translation>Błąd podczas zapisywania...</translation>
    </message>
    <message>
        <source>Closing previous database...</source>
        <translation>Zamykam poprzednią baze danych...</translation>
    </message>
    <message>
        <source>Do you want to save the changes?</source>
        <translation>Czy chcesz zapisać zmiany?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Tak</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nie</translation>
    </message>
    <message>
        <source>Error:</source>
        <translation>Błąd:</translation>
    </message>
    <message>
        <source>There is no selected item on the middle list box!</source>
        <translation type="obsolete">Nie zaznaczono zdnego elementu na środkowej listcie!</translation>
    </message>
    <message>
        <source>Do you really want to delete this?: 
%1</source>
        <translation>Czy napewno chcesz to skasować?:
%1</translation>
    </message>
    <message>
        <source>Confirmation</source>
        <translation>Potwierdzenie</translation>
    </message>
    <message>
        <source>Warning...</source>
        <translation>Uwaga...</translation>
    </message>
    <message>
        <source>There was some error during the scanning,
the DataBase may be incomplete</source>
        <translation type="obsolete">Wystąpił błąd podczas skanowania, 
baza danych może być niekompletna</translation>
    </message>
    <message>
        <source>There is no selected Media on the middle list box!</source>
        <translation type="obsolete">Nie zaznaczono zdnego elementu na środkowej listcie!</translation>
    </message>
    <message>
        <source>You can refresh ONLY a MEDIA node!</source>
        <translation>Możesz odświeżyć TYLKO wpisy o NOŚNIKACH!</translation>
    </message>
    <message>
        <source>An error occured while scanning, the rescan operation cancelled: 
%1</source>
        <translation type="obsolete">Wystąpił błąd podczas skanowania, opercja ponowenego skanowania anulowana:
%1</translation>
    </message>
    <message>
        <source>Insert a database file...</source>
        <translation>Wstaw plik bazy danych...</translation>
    </message>
    <message>
        <source>The Resoult:</source>
        <translation type="obsolete">Wynik:</translation>
    </message>
    <message>
        <source>The size of &quot;%1&quot; : 
 %2 
 %3 file /%4 directory</source>
        <translation>Rozmiar &quot;%1&quot; :
%2
%3 plików/%4 katalogów</translation>
    </message>
    <message>
        <source>Cannot mount CD</source>
        <translation>Nie można zamontować CD</translation>
    </message>
    <message>
        <source>Cannot eject CD!</source>
        <translation>Nie można wysunąć CD!</translation>
    </message>
    <message>
        <source>I can&apos;t find the &quot;mount&quot; program</source>
        <translation>Nie mogę odnaleść programu &quot;mount&quot;</translation>
    </message>
    <message>
        <source>Cannot mount CD!</source>
        <translation>Nie można zamontować CD!</translation>
    </message>
    <message>
        <source>Cannot eject CD</source>
        <translation>Nie można wysunąć CD</translation>
    </message>
    <message>
        <source>I can&apos;t find the &quot;eject&quot; program</source>
        <translation>Nie mogę odnaleść programu &quot;eject&quot;</translation>
    </message>
    <message>
        <source>Rename node...</source>
        <translation>Zmien nazwe wpisu...</translation>
    </message>
    <message>
        <source>Delete node</source>
        <translation>Skasuj wpis</translation>
    </message>
    <message>
        <source>Rescan media...</source>
        <translation>Skanuj ponownie nośnik...</translation>
    </message>
    <message>
        <source>Add media...</source>
        <translation>Dodaj nośnik...</translation>
    </message>
    <message>
        <source>Insert Catalog...</source>
        <translation>Wstaw Spis...</translation>
    </message>
    <message>
        <source>Rescan %1</source>
        <translation>Ponownie skanuj %1</translation>
    </message>
    <message>
        <source>View/Edit Comment...</source>
        <translation>Zobacz/Edytuj komentarz...</translation>
    </message>
    <message>
        <source>Show/Remove Content...</source>
        <translation>Pokaż/Usuń zawartość...</translation>
    </message>
    <message>
        <source>Node size</source>
        <translation>Rozmiar wpisu</translation>
    </message>
    <message>
        <source>Re-Number media...</source>
        <translation>Zmień numer nosnika...</translation>
    </message>
    <message>
        <source>Close all branch</source>
        <translation>Zwiń wszystkie gałęzie</translation>
    </message>
    <message>
        <source>It is NOT a media node!</source>
        <translation>To NIE jest Nośnik!</translation>
    </message>
    <message>
        <source>There is no selected item in the middle list box!</source>
        <translation>Nie zaznaczono żadnego elementu na środkowej listcie!</translation>
    </message>
    <message>
        <source>An error occured while scanning,
the DataBase may be incomplete</source>
        <translation>Wystąpił błąd podczas skanowania, 
baza danych może być niekompletna</translation>
    </message>
    <message>
        <source>There is no selected Media in the middle list box!</source>
        <translation>Nie zaznaczono żadnego nośnika na środkowej listcie!</translation>
    </message>
    <message>
        <source>An error occured while scanning, the rescan operation was cancelled: 
%1</source>
        <translation>Wystąpił błąd podczas skanowania, opercja ponowenego skanowania anulowana:
%1</translation>
    </message>
    <message>
        <source>Borrow this media to...</source>
        <translation>Pożycz ten nośnik...</translation>
    </message>
    <message>
        <source>Do you want to clear the borrowing mark from media &quot;%1&quot;?
(Say yes if you got it back.)</source>
        <translation>Czy chcesz usunąć oznaczenie pożyczenia z nośnika &quot;%1&quot;?
(Wybierz tak, jeśli go odzyskałeś.)</translation>
    </message>
    <message>
        <source>I got it back! (clear borrowing mark)</source>
        <translation>Odzyskałem! (usuń oznaczenie pożyczenia)</translation>
    </message>
    <message>
        <source>The database file has newer version than this version of cdcat knows:
I understand maximum %1 datafile version but readed %2

Strongly recommended to upgrade your cdcat!!!
Homepage: %3</source>
        <translation type="obsolete">Plik z bazą danych pochodzi z nowszej wersji cdcat&apos;a:
Rozumiem maksymalnie wersje %1 bazy danych, ale odczytałem %2

Zachęcam do zainstalowania nowej wersji cdcat&apos;a!!!
Strona domowa: %3</translation>
    </message>
    <message>
        <source>Catalog Link</source>
        <translation>Łącze do katalogu</translation>
    </message>
    <message>
        <source>Follow the link (Open it) !</source>
        <translation>Podążaj za łączem (Otwórz je) !</translation>
    </message>
    <message>
        <source>Add a link to a CdCAt Catalog...</source>
        <translation>Dodaj łącze do katalogu CdCat&apos;a...</translation>
    </message>
    <message>
        <source>The link is empty.</source>
        <translation>Łącze jest puste.</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Numer</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <source>The database file has newer version than this version of cdcat can work with:
I understand maximum %1 datafile version but readed %2

Strongly recommended to upgrade your cdcat!!!
Homepage: %3</source>
        <translation>Plik z bazą danych pochodzi z nowszej wersji niż taka jaką potrafie oczytać:
Rozumiem maksymalnie wersje %1 bazy danych, ale odczytałem %2

Zachęcam do zainstalowania nowej wersji cdcat&apos;a!!!
Strona domowa: %3</translation>
    </message>
    <message>
        <source>No database opened.</source>
        <translation>Nie otwarto żadnej bazy danych.</translation>
    </message>
    <message>
        <source>No item selected.</source>
        <translation>Niewybrano żadnego elementu.</translation>
    </message>
    <message>
        <source>The resoult:</source>
        <translation>Rezultat:</translation>
    </message>
</context>
<context>
    <name>HDirectoryView</name>
    <message>
        <source>Directory Tree</source>
        <translation>Drzewo katalogów</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopiuj</translation>
    </message>
    <message>
        <source>Move</source>
        <translation>Przenieś</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Łącz</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Nieznane</translation>
    </message>
    <message>
        <source>Drop target</source>
        <translation>Pomiń cel</translation>
    </message>
    <message>
        <source>Not implemented</source>
        <translation>Nie zaimplementowane</translation>
    </message>
    <message>
        <source>Drag source</source>
        <translation>Przeciągnij źródło</translation>
    </message>
    <message>
        <source>Delete </source>
        <translation>Kasuj</translation>
    </message>
</context>
<context>
    <name>HQListView</name>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
</context>
<context>
    <name>ImportDialog</name>
    <message>
        <source>Create new Database</source>
        <translation>Stwórz nową baze danych</translation>
    </message>
    <message>
        <source>Choose a file to import:</source>
        <translation type="obsolete">Wybierz plik do zimportowania:</translation>
    </message>
    <message>
        <source>Seperator:</source>
        <translation type="obsolete">Separator:</translation>
    </message>
    <message>
        <source>This is the seperator in dataline
&lt;path&gt;SEPERATOR&lt;size&gt;SEPERATOR&lt;date&gt;&lt;space&gt;&lt;time&gt;</source>
        <translation type="obsolete">To jest separator w lini danych
&lt;ścieżka&gt;SEPERATOR&lt;rozmiar&gt;SEPERATOR&lt;data&gt;&lt;rozmiar&gt;&lt;czas&gt;</translation>
    </message>
    <message>
        <source>Seperator in data line</source>
        <translation type="obsolete">Separator w lini danych</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Import</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Open file dialog</source>
        <translation>Okno wyboru pliku do otwarcia</translation>
    </message>
    <message>
        <source>Corrects bad output style (gtktalog)</source>
        <translation>Popraw zły sposób zapisu (gtktalog)</translation>
    </message>
    <message>
        <source>Error:</source>
        <translation>Błąd:</translation>
    </message>
    <message>
        <source>You must be fill the &quot;Filename&quot; field!</source>
        <translation>Musisz uzupełnić pole &quot;Nazwa pliku&quot;!</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>You must be fill the &quot;Seperator&quot; field!</source>
        <translation type="obsolete">Musisz uzupełnić pole &quot;Seperator&quot;!</translation>
    </message>
    <message>
        <source>csv files(*.csv)</source>
        <translation>pliki csv(*.csv)</translation>
    </message>
    <message>
        <source>open file dialog</source>
        <translation>Okno wyboru pliku do otwarcia</translation>
    </message>
    <message>
        <source>Choose a file for import</source>
        <translation>Wybierz plik do zimportowania</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Correct bad style of gtktalog export</source>
        <translation type="obsolete">Popraw zły sposób eksportu z gtktalog</translation>
    </message>
    <message>
        <source>Import database (csv/gtktalog)</source>
        <translation type="obsolete">Importuj baze danych (csv/gtkatalog)</translation>
    </message>
    <message>
        <source>&amp;Text (csv)</source>
        <translation>&amp;Text (csv)</translation>
    </message>
    <message>
        <source>&amp;XML (gtktalog)</source>
        <translation type="obsolete">&amp;XML (gtktalog)</translation>
    </message>
    <message>
        <source>Select the type of import</source>
        <translation type="obsolete">Wybierz rodzaj importowania</translation>
    </message>
    <message>
        <source>Select this for importing a text/csv</source>
        <translation type="obsolete">Użyj tego do importowania tekstu/csv</translation>
    </message>
    <message>
        <source>Select this for importing a xml report generated from gtktalog</source>
        <translation type="obsolete">Użyj tego do importowania raportu xml wygenerowanego przez gtktalog</translation>
    </message>
    <message>
        <source>Open the file browser for selecting a file to import.</source>
        <translation type="obsolete">Otwóż przeglądarke plików w celu wybrania pliku do zimportowania.</translation>
    </message>
    <message>
        <source>Corrects bad output style of gtktalog.
&lt;media&gt;SEPERATOR/&lt;dir&gt;/SEPERATOR/&lt;dir&gt;SEPERATOR&lt;
 will be to
&lt;media&gt;/&lt;dir&gt;/&lt;dir&gt;</source>
        <translation type="obsolete">Naprawia zły styl zapisu gtktalog&apos;a.
&lt;nośnik&gt;SEPERATOR/&lt;katalog&gt;/SEPERATOR/&lt;katalog&gt;SEPERATOR
zostanie zmieniony na
&lt;nośnik&gt;/&lt;katalog&gt;/&lt;katalog&gt;</translation>
    </message>
    <message>
        <source>&lt;strong&gt;Please read the README_IMPORT before you import!&lt;/strong&gt;</source>
        <translation>&lt;strong&gt;Prosze przeczytać README_IMPORT zanim zaczniesz importować!&lt;/strong&gt;</translation>
    </message>
    <message>
        <source>xml files(*.xml)</source>
        <translation>pliki xml(*.xml)</translation>
    </message>
    <message>
        <source>Import CSV file</source>
        <translation>Importuj plik CSV</translation>
    </message>
    <message>
        <source>File:</source>
        <translation>Plik:</translation>
    </message>
    <message>
        <source>Select this for importing text file (csv)</source>
        <translation type="obsolete">Zaznacz to aby importować plik tekstowy (csv)</translation>
    </message>
    <message>
        <source>Select this for importing a xml report generated with gtktalog</source>
        <translation type="obsolete">Zaznacz to aby importować plik xml wygenerowany w gtktalog</translation>
    </message>
    <message>
        <source>File dialog for selecting file to import.</source>
        <translation type="obsolete">Okno wyboru pliku do importowania.</translation>
    </message>
    <message>
        <source>Corrects bad output style of gtktalog.
&lt;media&gt;SEPERATOR/&lt;dir&gt;/SEPERATOR/&lt;dir&gt;
 will be to
&lt;media&gt;/&lt;dir&gt;/&lt;dir&gt;</source>
        <translation type="obsolete">Naprawia zły styl zapisu gtktalog&apos;a.
&lt;nośnik&gt;SEPERATOR/&lt;katalog&gt;/SEPERATOR/&lt;katalog&gt;
zostanie zmieniony na
&lt;nośnik&gt;/&lt;katalog&gt;/&lt;katalog&gt;</translation>
    </message>
    <message>
        <source>&amp;Text (CSV)</source>
        <translation type="obsolete">&amp;Text (CSV)</translation>
    </message>
    <message>
        <source>Select this for importing text file (CSV)</source>
        <translation type="obsolete">Zaznacz to aby importować plik tekstowy (CSV)</translation>
    </message>
    <message>
        <source>Select this for importing a XML report generated with gtktalog</source>
        <translation type="obsolete">Zaznacz to aby importować plik XML wygenerowany w gtktalog</translation>
    </message>
    <message>
        <source>You must fill the &quot;Filename&quot; field!</source>
        <translation type="obsolete">Musisz uzupełnić pole &quot;Nazwa pliku&quot;!</translation>
    </message>
    <message>
        <source>You must fill the &quot;Seperator&quot; field!</source>
        <translation type="obsolete">Musisz uzupełnić pole &quot;Seperator&quot;!</translation>
    </message>
    <message>
        <source>Correct bad style from gtktalog export</source>
        <translation>Popraw zły styl z ekspotu gtktalog&apos;u</translation>
    </message>
    <message>
        <source>Separator:</source>
        <translation>Separator:</translation>
    </message>
    <message>
        <source>This is the separator in dataline
&lt;path&gt;SEPARATOR&lt;size&gt;SEPARATOR&lt;date&gt;&lt;space&gt;&lt;time&gt;</source>
        <translation>To jest separator w lini danych
&lt;ścieżka&gt;SEPERATOR&lt;rozmiar&gt;SEPERATOR&lt;data&gt;&lt;rozmiar&gt;&lt;czas&gt;</translation>
    </message>
    <message>
        <source>Separator in data line</source>
        <translation>Separator w lini danych</translation>
    </message>
    <message>
        <source>Gtktalog &amp;XML</source>
        <translation>Gtktalog &amp;XML</translation>
    </message>
    <message>
        <source>&amp;WhereIsIt XML (classic)</source>
        <translation>&amp;WhereIsIt XML (klasyczny)</translation>
    </message>
    <message>
        <source>Select the type of import here</source>
        <translation>Tutaj wybierz typ importu</translation>
    </message>
    <message>
        <source>Select this for importing a text import (csv)</source>
        <translation>Użyj tego do importowania zimportowanego tekstu (csv)</translation>
    </message>
    <message>
        <source>Select this for importing a xml report generated frm gtktalog</source>
        <translation>Użyj tego do importowania raportu xml wygenerowanego przez gtktalog</translation>
    </message>
    <message>
        <source>Open the file dialog for selecting file to import.</source>
        <translation>Otwóż przeglądarke plików w celu wybrania pliku do zimportowania.</translation>
    </message>
    <message>
        <source>Corrects bad output style from gtktalog.
&lt;media&gt;SEPARATOR/&lt;dir&gt;/SEPARATOR/&lt;dir&gt;
 will be to
&lt;media&gt;/&lt;dir&gt;/&lt;dir&gt;</source>
        <translation>Naprawia zły styl zapisu gtktalog&apos;a.
&lt;nośnik&gt;SEPERATOR/&lt;katalog&gt;/SEPERATOR/&lt;katalog&gt;
zostanie zmieniony na
&lt;nośnik&gt;/&lt;katalog&gt;/&lt;katalog&gt;</translation>
    </message>
    <message>
        <source>You must be fill the &quot;Separator&quot; field!</source>
        <translation>Musisz uzupełnić pole &quot;Separator&quot;!</translation>
    </message>
    <message>
        <source>all files(*.*)</source>
        <translation>wszystkie pliki (*.*)</translation>
    </message>
</context>
<context>
    <name>InfoDialog</name>
    <message>
        <source>German translation &amp; additional programming</source>
        <translation>Tłumaczenie niemieckie oraz dodakowe programowanie</translation>
    </message>
    <message>
        <source>Spanish translation</source>
        <translation>Hiszpańskie tłumaczenie</translation>
    </message>
    <message>
        <source>Czech translation</source>
        <translation>Czeskie tłumaczenie</translation>
    </message>
    <message>
        <source>About cdcat</source>
        <translation>O CDCat</translation>
    </message>
    <message>
        <source>close</source>
        <translation>zamknij</translation>
    </message>
    <message>
        <source>About Cdcat</source>
        <translation>O CDCat</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Licencja</translation>
    </message>
    <message>
        <source>Thanks</source>
        <translation>Podziękowania</translation>
    </message>
    <message>
        <source>-= CdCatalog by Hyper =-</source>
        <translation>-= CdCatalog by Hyper =-</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Wersja:</translation>
    </message>
    <message>
        <source>Author:</source>
        <translation>Autor:</translation>
    </message>
    <message>
        <source>Copyright (C) 2003 Peter Deak (GPL)</source>
        <translation></translation>
    </message>
    <message>
        <source>Polish translation</source>
        <translation type="obsolete">Polskie Tłumaczenie</translation>
    </message>
    <message>
        <source>AVI reader plugin &amp; Polish translation</source>
        <translation>Wtyczka do odczytywania plikow AVI &amp; Polskie Tlumaczenie</translation>
    </message>
</context>
<context>
    <name>PWw</name>
    <message>
        <source>Please Wait...</source>
        <translation>Prosze czekać...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Directory</source>
        <translation>Katalog</translation>
    </message>
    <message>
        <source>Unreadable Directory</source>
        <translation>Katalog Niedostępny</translation>
    </message>
    <message>
        <source>Catalog</source>
        <translation>Spis</translation>
    </message>
    <message>
        <source>Unknown(DB)</source>
        <translation>Nieznany(DB)</translation>
    </message>
    <message>
        <source>CD</source>
        <translation>CD</translation>
    </message>
    <message>
        <source>DVD</source>
        <translation>DVD</translation>
    </message>
    <message>
        <source>HardDisc</source>
        <translation>Dysk Twardy</translation>
    </message>
    <message>
        <source>Floppy</source>
        <translation>Dyskietka</translation>
    </message>
    <message>
        <source>NetworkDrv</source>
        <translation>Napęd Sieciowy</translation>
    </message>
    <message>
        <source>FlashDrv</source>
        <translation>Napęd Flash</translation>
    </message>
    <message>
        <source>OtherDevice</source>
        <translation>Inne urządzenie</translation>
    </message>
    <message>
        <source>Video:
</source>
        <translation>Wideo:</translation>
    </message>
    <message>
        <source>Total Time</source>
        <translation>Czas całkowity</translation>
    </message>
    <message>
        <source>Framerate</source>
        <translation>Klatek na sekunde</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Roździelczość</translation>
    </message>
    <message>
        <source>Audio:</source>
        <translation>Audio:</translation>
    </message>
    <message>
        <source>More Data:</source>
        <translation>Więcej informacji:</translation>
    </message>
    <message>
        <source>Artist</source>
        <translation>Artysta</translation>
    </message>
    <message>
        <source>Comments</source>
        <translation>Komentarz</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation>Prawa Autorskie</translation>
    </message>
    <message>
        <source>Creation Date</source>
        <translation>Data Utworzenia</translation>
    </message>
    <message>
        <source>Engineer</source>
        <translation>Inżynier</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Product</source>
        <translation>Produkt</translation>
    </message>
    <message>
        <source>Software</source>
        <translation>Oprogramowanie</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>Źródło</translation>
    </message>
    <message>
        <source>Subject</source>
        <translation>Temat</translation>
    </message>
    <message>
        <source>Technician</source>
        <translation>Technik</translation>
    </message>
    <message>
        <source>Unknown/not implemented/broken header
</source>
        <translation>Nieznane/brak implementacji/uszkodzony nagłówek
</translation>
    </message>
    <message>
        <source>Channels</source>
        <translation>Kanały</translation>
    </message>
    <message>
        <source>Samples/s</source>
        <translation type="obsolete">Próbek/sek</translation>
    </message>
    <message>
        <source>Bitrate</source>
        <translation>Bitrate</translation>
    </message>
    <message>
        <source>Genre</source>
        <translation>Gatunek</translation>
    </message>
    <message>
        <source>Not a RIFF/AVI file OR header broken!</source>
        <translation>Plik nie jest plikiem RIFF/AVI albo uszkodzony nagłowek!</translation>
    </message>
    <message>
        <source>Sample/s</source>
        <translation>Próbek/s</translation>
    </message>
</context>
<context>
    <name>SelReadable</name>
    <message>
        <source>Select readable items</source>
        <translation>Wybierz odczywywane pliki</translation>
    </message>
    <message>
        <source>Read mp3 tags</source>
        <translation>Czytaj tagi mp3</translation>
    </message>
    <message>
        <source>Store content of some files</source>
        <translation>Zapisz zawartość niektórych plików</translation>
    </message>
    <message>
        <source>; separated list of readable file patterns</source>
        <translation>lista plików podzelona separatorami &quot;;&quot; </translation>
    </message>
    <message>
        <source>content size limit in kByte</source>
        <translation>Maksymalny rozmiar plików któych zawartość jest zapisywana</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Default tag</source>
        <translation>Domyślny tag</translation>
    </message>
    <message>
        <source>version</source>
        <translation>wersja</translation>
    </message>
    <message>
        <source>Read mp3 technical info as comment (bitrate,freq,length...)</source>
        <translation>Odczytaj dane techniczne o mp3 jako komentarz (bitare,częstotliwość,czas...)</translation>
    </message>
    <message>
        <source>Read avi technical info as comment (codecs,lenhth,...)</source>
        <translation>Odczytaj informacje o pliku AVI jako komentarz (Kodek,długość,...)</translation>
    </message>
</context>
<context>
    <name>ShowContent</name>
    <message>
        <source>%1 kByte</source>
        <translation>%1 kByte</translation>
    </message>
    <message>
        <source>Remove the file content from the database. (Warning: Unrecoverable!)</source>
        <translation>Usunąc zawartość pliku z bazy danych. (Uwaga: nieodwracalne!)</translation>
    </message>
    <message>
        <source>Save this content to a new file</source>
        <translation>Zapisz tą zawartośc do nowego pliku</translation>
    </message>
    <message>
        <source>Content of %1</source>
        <translation>Zawartość %1</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Save content...</source>
        <translation>Zapisz zawartość...</translation>
    </message>
    <message>
        <source>Select a filename below</source>
        <translation>Wybierz plik z listy</translation>
    </message>
    <message>
        <source>I can&apos;t rewrite the file: %1</source>
        <translation>Nie mogę nadpisać pliku: %1</translation>
    </message>
    <message>
        <source>Error while saving...</source>
        <translation>Błąd podczas zapisywania...</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Confirmation</source>
        <translation>Potwierdzenie</translation>
    </message>
    <message>
        <source>Are you sure want to delete this file&apos;s content from the database?</source>
        <translation type="obsolete">Jeśteś pewny, że chcesz skasować zawartośc tego pliku z bazy danych?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Tak</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nie</translation>
    </message>
    <message>
        <source>Sure to delete this file&apos;s content from the database?</source>
        <translation>Napewno skasować zawartość tego pliku z bazy danych?</translation>
    </message>
</context>
<context>
    <name>addDialog</name>
    <message>
        <source>Directory Browser</source>
        <translation>Przeglądarka katalogów</translation>
    </message>
    <message>
        <source>New Disk %1</source>
        <translation>Nowy dysk %1</translation>
    </message>
    <message>
        <source>Add Media to the Database</source>
        <translation>Dodaj nowy nośnik do bazdy danych</translation>
    </message>
    <message>
        <source>Choose a directory to scan:</source>
        <translation>Wybierz katalog do skanowania:</translation>
    </message>
    <message>
        <source>Media Name:</source>
        <translation>Nazwa nośnika:</translation>
    </message>
    <message>
        <source>Serial number of Media:</source>
        <translation>Numer seryjny nośnika:</translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation>Właściciel:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Komentarz:</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>OK / Scan</source>
        <translation>OK / Skanuj</translation>
    </message>
    <message>
        <source>CD</source>
        <translation>CD</translation>
    </message>
    <message>
        <source>DVD</source>
        <translation>DVD</translation>
    </message>
    <message>
        <source>HardDisc</source>
        <translation>Dysk Twardy</translation>
    </message>
    <message>
        <source>Floppy</source>
        <translation>Dyskietka</translation>
    </message>
    <message>
        <source>NetworkPlace</source>
        <translation>Miejsce w sieći</translation>
    </message>
    <message>
        <source>FlashDrive</source>
        <translation>Napęd Flash</translation>
    </message>
    <message>
        <source>OtherDevice</source>
        <translation>Inne urządzenie</translation>
    </message>
    <message>
        <source>Error:</source>
        <translation>Błąd:</translation>
    </message>
    <message>
        <source>You must be fill the &quot;Name&quot; field!</source>
        <translation>Musisz uzupełnić pole &quot;nazwa&quot;!</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>You aren&apos;t selected a directory! Please select one!</source>
        <translation type="obsolete">Nie wybrałeś żadnego katalogu! Prosze, wybierz jakiś!</translation>
    </message>
    <message>
        <source>The Media Name must be unique! Please change it!</source>
        <translation>Nazwa Nośnika musi być unikatowa! Prosze zmienić ją!</translation>
    </message>
    <message>
        <source>The Value of Serial Number must be unique! Please change the value!</source>
        <translation type="obsolete">Numer seryjny musi być unikatowy! Prosze go zmienić!</translation>
    </message>
    <message>
        <source>Select readable items</source>
        <translation>Wybierz odczywywane pliki</translation>
    </message>
    <message>
        <source>The Value of Serial Number must be unique! Please change it!</source>
        <translation>Numer seryjny musi być unikatowy! Prosze go zmienić!</translation>
    </message>
    <message>
        <source>You haven&apos;t selected a directory! Please select one!</source>
        <translation>Nie wybrałeś żadnego katalogu! Prosze, wybierz jakiś!</translation>
    </message>
    <message>
        <source>The media name can&apos;t begin with the &quot;@&quot; character!</source>
        <translation>Nazwa nośnika nie może zaczynać się od znaku &quot;@&quot;!</translation>
    </message>
</context>
<context>
    <name>borrowDialog</name>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>I borrow the &quot;%1&quot; named media to:</source>
        <translation>Pożyczam nośnik nazwany &quot;%1&quot; :</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>nieznany</translation>
    </message>
    <message>
        <source>I borrow the &quot;&quot; named media to:</source>
        <translation>Pożyczam nośnik nazwany &quot;&quot; :</translation>
    </message>
    <message>
        <source>Borrowing...</source>
        <translation>Pożyczanie...</translation>
    </message>
</context>
<context>
    <name>borrowingDialog</name>
    <message>
        <source>Borrwing info...</source>
        <translation type="obsolete">Pożyczanie...</translation>
    </message>
    <message>
        <source>Media borrowing info:</source>
        <translation>Informacja o pożyczaniu nośników:</translation>
    </message>
    <message>
        <source>Only show borrowed items</source>
        <translation type="obsolete">Pokazuj tylko pożyczone pozycje</translation>
    </message>
    <message>
        <source>Clear all borrowing</source>
        <translation type="obsolete">Usuń wszystkie oznacznia pożyczenia</translation>
    </message>
    <message>
        <source>Media</source>
        <translation>Nośnik</translation>
    </message>
    <message>
        <source>Borrowed</source>
        <translation>Pożyczone</translation>
    </message>
    <message>
        <source>where is it now?</source>
        <translation>Gdzie teraz jest?</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nie</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Tak</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>nieznane</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
    <message>
        <source>Set &quot;Yes&quot; or &quot;No&quot; !</source>
        <translation>Wybierz &quot;Tak&quot; lub &quot;Nie&quot; !</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Uwaga</translation>
    </message>
    <message>
        <source>Do you save the changes?</source>
        <translation>Zapisać zmiany?</translation>
    </message>
    <message>
        <source>Are you sure want to clear all borrow?</source>
        <translation>Czy napewno chcesz odznaczyć wszystkie pożyczenia?</translation>
    </message>
    <message>
        <source>I got it back!</source>
        <translation>Odzyskałem go!</translation>
    </message>
    <message>
        <source>&lt;&lt; </source>
        <translation>&lt;&lt;</translation>
    </message>
    <message>
        <source>Borrowing info...</source>
        <translation>Pożyczanie...</translation>
    </message>
    <message>
        <source>Show only borrowed items</source>
        <translation>Pokaż tylko porzyczone nośniki</translation>
    </message>
    <message>
        <source>Clear all borrowing info</source>
        <translation>Usuń wszystkie informacje o porzyczaniu</translation>
    </message>
</context>
<context>
    <name>commentEdit</name>
    <message>
        <source>Edit Comment</source>
        <translation>Edytuj komentarz</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>exportCdcatDB</name>
    <message>
        <source>exportCdcatDB database</source>
        <translation type="obsolete">eksporuj baze danych CdCatDB </translation>
    </message>
    <message>
        <source>Availiable media</source>
        <translation>Dostępne nośniki</translation>
    </message>
    <message>
        <source>Media to export</source>
        <translation>Nośniki do wyeksportowania</translation>
    </message>
    <message>
        <source>All media</source>
        <translation>Wszystkie nośniki</translation>
    </message>
    <message>
        <source>separator:</source>
        <translation>separator:</translation>
    </message>
    <message>
        <source>File to export:</source>
        <translation>Plik do zapisania:</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancel</translation>
    </message>
    <message>
        <source>exportCdcatDB database: </source>
        <translation type="obsolete">eksporuj baze danych CdCatDB:</translation>
    </message>
    <message>
        <source>Filename missing</source>
        <translation>Brakuje nazwy pliku</translation>
    </message>
    <message>
        <source>Please enter a filename!</source>
        <translation>Prosze podać nazwe pliku!</translation>
    </message>
    <message>
        <source>Separator missing</source>
        <translation>Brakuje separatora</translation>
    </message>
    <message>
        <source>Please enter a separator!</source>
        <translation>Prosze podać separator!</translation>
    </message>
    <message>
        <source>Error during write config...</source>
        <translation>Błąd podczas zapisywania pliku konfiguracyjnego...</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>All files (*.*)</source>
        <translation>Wszytkie pliki (*.*)</translation>
    </message>
    <message>
        <source>file chooser</source>
        <translation>Wybierasz plików</translation>
    </message>
    <message>
        <source>Choose a file!</source>
        <translation>Wybierz plik!</translation>
    </message>
    <message>
        <source>Add media</source>
        <translation>Dodaj nośnik</translation>
    </message>
    <message>
        <source>Remove media</source>
        <translation>Usuń nośnik</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>export as HTML</source>
        <translation>Eksportuj do HTML</translation>
    </message>
    <message>
        <source>export as CSV</source>
        <translation>Eksportuj do CSV</translation>
    </message>
    <message>
        <source>Media</source>
        <translation>Nośnik</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Plik</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Ostatnia zmiana</translation>
    </message>
    <message>
        <source>I can&apos;t create or rewrite the file</source>
        <translation>Nie mogę utworzyć lub przemianować pliku</translation>
    </message>
    <message>
        <source>Export from cdcat:</source>
        <translation>Eksportuj z CdCat:</translation>
    </message>
    <message>
        <source>Export database...</source>
        <translation>Eksportuj baze danych...</translation>
    </message>
    <message>
        <source>What to export</source>
        <translation>Co eksportować</translation>
    </message>
    <message>
        <source>Only media name</source>
        <translation>Tylko nazwy nośników</translation>
    </message>
    <message>
        <source>Media name</source>
        <translation>Nazwa nośnika</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Ścieżka</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Komentarz</translation>
    </message>
    <message>
        <source>HTML headline</source>
        <translation>Nagłówek HTML</translation>
    </message>
    <message>
        <source>table header</source>
        <translation>nagłówek tabeli</translation>
    </message>
    <message>
        <source>Overwrite?</source>
        <translation>Nadpisać?</translation>
    </message>
    <message>
        <source>Do you want overwrite this file?</source>
        <translation>Czy chcesz nadpisać ten plik?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Tak</translation>
    </message>
    <message>
        <source>Discard</source>
        <translation>Odrzuć</translation>
    </message>
    <message>
        <source>Export CdCat database: </source>
        <translation>Eksportuj baze danych CdCat:</translation>
    </message>
</context>
<context>
    <name>findDialog</name>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Media</source>
        <translation>Nośnik</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Ścieżka</translation>
    </message>
    <message>
        <source>Modification</source>
        <translation>Data zmiany</translation>
    </message>
    <message>
        <source>Search in the database...</source>
        <translation>Szukaj w bazie danych...</translation>
    </message>
    <message>
        <source>Close / Go to selected</source>
        <translation>Zamknij / Przejdź do wybranego</translation>
    </message>
    <message>
        <source>Find:</source>
        <translation>Znajdź:</translation>
    </message>
    <message>
        <source>Seek in:</source>
        <translation>Szukaj w:</translation>
    </message>
    <message>
        <source>Owner:</source>
        <translation>Właściciel:</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Komentarz</translation>
    </message>
    <message>
        <source>File name</source>
        <translation>Nazwa pliku</translation>
    </message>
    <message>
        <source>Directory name</source>
        <translation type="obsolete">Nazwa katalogu</translation>
    </message>
    <message>
        <source>mp3-tag Comment</source>
        <translation>mp3-tag Komentarz</translation>
    </message>
    <message>
        <source>mp3-tag Album</source>
        <translation>mp3-tag Album</translation>
    </message>
    <message>
        <source>mp3-tag Title</source>
        <translation>mp3-tag Tytuł</translation>
    </message>
    <message>
        <source>mp3-tag Artist</source>
        <translation>mp3-tag Artysta</translation>
    </message>
    <message>
        <source>Case sensitive</source>
        <translation>Czuły na wielkość liter</translation>
    </message>
    <message>
        <source>Use easy matching instead regex</source>
        <translation>Użyj łatwego szukania zamiast regex&apos;ów</translation>
    </message>
    <message>
        <source>All/Everybody</source>
        <translation>Każdy/Wszyscy</translation>
    </message>
    <message>
        <source>All media</source>
        <translation>Wszystkie nośniki</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancel</translation>
    </message>
    <message>
        <source>Results</source>
        <translation>Wyniki</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Zawartość</translation>
    </message>
    <message>
        <source>Media / Directory name</source>
        <translation>Nośnik / Nazwa katalogu</translation>
    </message>
</context>
<context>
    <name>helpDialog</name>
    <message>
        <source>help</source>
        <translation>pomoc</translation>
    </message>
    <message>
        <source>close</source>
        <translation>zamknij</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;center&quot;&gt;&lt;font size=&quot;+1&quot;&gt;&lt;b&gt;Help&lt;/b&gt;&lt;/font&gt;&lt;/p&gt;&lt;br&gt;

&lt;b&gt;What&apos;s this?&lt;/b&gt;&lt;br&gt;
&lt;blockquote&gt;
The cdcat is graphical (QT based) multiplatform (Linux/Windows) catalog program which scans the directories/drives you want and memorize the filesystem including the tags of mp3&apos;s and other data and store it in a small file.
The database is stored in a gzipped XML format, so you can hack it, or use it if necessary :-)
And the program can store the content of some specified files up to a limit size if you want. (for example: *.nfo)
&lt;/blockquote&gt;
&lt;br&gt;
&lt;b&gt;Usage:&lt;/b&gt;&lt;br&gt;
&lt;blockquote&gt;
&lt;i&gt;Create a new catalog&lt;/i&gt;: Run the &lt;tt&gt;New&lt;/tt&gt; command in the catalog menu. You have to type the name of the new catalog. You can specify the default username of the media(which you scan later), and add a comment to the catalog.&lt;br&gt;Before the scanning select the necessary readable components in the config dialog, which can be mp3 tags content of some files or etc.  If you done this, you can scan one of your media with &lt;tt&gt;Add media&lt;/tt&gt;command in the Edit menu. In that dialog you have to specyfi the directory/or drive the media you want to add. It&apos;s recommended to specify the name and the number of the media which has to be unique. (The program always generate one identical name and number) You can label the media to a owner, if necessary.
&lt;br&gt;If you scanned your media, you will be able to browse in it with the browser window (like mc) , or search in it. You can save the catalog with &lt;tt&gt;save as&lt;/tt&gt; command in the Catalog menu.
&lt;br&gt;
&lt;br&gt;
&lt;i&gt;Open an existing catalog:&lt;/i&gt;Run the &lt;tt&gt;open&lt;/tt&gt; command in the Catalog menu, and choice the file of the catalog. (*.hcf)  After the opening you will be able browse the catalog or search in it.
&lt;br&gt;
&lt;/blockquote&gt;
&lt;br&gt;
&lt;b&gt;Author:&lt;/b&gt;
&lt;blockquote&gt;The program was written by  Peter Deak  (hungary)&lt;br&gt;
E-mail: hyperr@freemail.hu
&lt;br&gt;
&lt;br&gt;Thanks for my girlfriend Ani who was my fist beta tester, and she encuraged me to write this program. 
&lt;/blockquote&gt;
&lt;br&gt;
&lt;b&gt;License:&lt;/b&gt;
&lt;blockquote&gt;General Public License (GPL)&lt;/blockquote&gt;
&lt;br&gt;
&lt;b&gt;Homepage:&lt;/b&gt;
&lt;blockquote&gt;You can read about the program and get new versions, sources etc, in the hompage of cdcat:&lt;br&gt;&lt;tt&gt;http://cdcat.sourceforge.net&lt;/tt&gt;&lt;/blockquote&gt;</source>
        <translation type="obsolete">&lt;p align=&quot;center&quot;&gt;&lt;font size=&quot;+1&quot;&gt;&lt;b&gt;Pomoc&lt;/b&gt;&lt;/font&gt;&lt;/p&gt;&lt;br&gt;

&lt;b&gt;Co to jest?&lt;/b&gt;&lt;br&gt;
&lt;blockquote&gt;
CdCat jest graficznym (Oparty na QT) wieloplatformowym (Linux/Windows) programem do katalogowania, który skanuje wybrane katalogi/dyski i zapisuje całość wraz z tagami mp3 oraz innymi danymi do małych plików.
Baza danych jest zapisana w gzip&apos;powanym XML&apos;u, tak żebyś zawsze mógł się nim zabawić, albo odczytać w razie potrzeby :-)
Na żądanie program może także zapisać zawartość odpowiednio małych plików. (na przykład: *.nfo)
&lt;/blockquote&gt;
&lt;br&gt;
&lt;b&gt;Użycie:&lt;/b&gt;&lt;br&gt;
&lt;blockquote&gt;
&lt;i&gt;Utwórz nowy katalog&lt;/i&gt;: Wybierz polecenie &lt;tt&gt;Nowy&lt;/tt&gt; z menu Katalog. Musisz podać nazwe nowego katalogu. Możesz podać nazwe domyślnego właściciela nośnika(który bedzie potem skanowany), oraz dodać komentarz do katalogu.&lt;br&gt;Przed rozpoczęciem skanowania, z menu konfigracji, wybierz dane które także mają być zapisywane, mogą to być tagi mp3, zawartoś określonych plików itp. Po tym, możesz rozpocząć skanowanie poleceniem &lt;tt&gt;Dodaj nośnik&lt;/tt&gt; z menu Edycji. W nowym okienku musisz wybrać katalog/dysk który chcesz dodać. Zaleca się podanie nazwy oraz numeru nośnika która muśi być unikatowa. (Program sam generuje nazwe i numer) Możesz przypisać nośnik danemu użytkownikowi w razie potrzeby. 
&lt;br&gt;Jeśli juz zeskanowałeś nośniki, możesz je przeglądać w oknie przeglądarki (tak jak w mc), albo czegoś poszukać. Możesz zapisać katalog poleceniem &lt;tt&gt;Zapisz jako&lt;/tt&gt; z menu Katalog.
&lt;br&gt;
&lt;br&gt;
&lt;i&gt;Otwórz istniejący katalog:&lt;/i&gt; Wybierz polecenie &lt;tt&gt;otwórz&lt;/tt&gt; z menu Katalog, a następnie otwórz plik z katalogiem. (*.hcf) Następnie możesz normalnie przeglądać katalog i go przeszukiwać. 
&lt;br&gt;
&lt;/blockquote&gt;
&lt;br&gt;
&lt;b&gt;Autor:&lt;/b&gt;
Program został napisany przez  Peter Deak  (Węgry)&lt;br&gt;
E-Mail: hyperr@freemail.hu
&lt;br&gt;
&lt;br&gt;Podziękowania dla mojej dziewczyny Ani, która była moim pierwszym betatesterem, i zachęcała mnie do pisani tego programu.
&lt;/blockquote&gt;
&lt;br&gt;
&lt;b&gt;Licencja:&lt;/b&gt;
&lt;blockquote&gt;eneral Public License (GPL)&lt;/blockquote&gt;
&lt;br&gt;
&lt;b&gt;Strona domowa:&lt;/b&gt;
&lt;blockquote&gt;Możesz poczytać o programie, sciągnąc nowa wersje, źródła itp. ze strony domowej CdCat&apos;a:&lt;br&gt;&lt;tt&gt;http://cdcat.sourceforge.net&lt;/tt&gt;&lt;/blockquote&gt;</translation>
    </message>
    <message>
        <source>&lt;p align=&quot;center&quot;&gt;&lt;font size=&quot;+1&quot;&gt;&lt;b&gt;Help&lt;/b&gt;&lt;/font&gt;&lt;/p&gt;&lt;br&gt;

&lt;b&gt;What&apos;s this?&lt;/b&gt;&lt;br&gt;
&lt;blockquote&gt;
The cdcat is graphical (QT based) multiplatform (Linux/Windows) catalog program which scans the directories/drives you want and memorize the filesystem including the tags of mp3&apos;s and other data and store it in a small file.
The database is stored in a gzipped XML format, so you can hack it, or use it if necessary :-)
And the program can store the content of some specified files up to a limit size if you want. (for example: *.nfo)
&lt;/blockquote&gt;
&lt;br&gt;
&lt;b&gt;Usage:&lt;/b&gt;&lt;br&gt;
&lt;blockquote&gt;
&lt;i&gt;Create a new catalog&lt;/i&gt;: Run the &lt;tt&gt;New&lt;/tt&gt; command in the catalog menu. You have to type the name of the new catalog. You can specify the default username of the media(which you scan later), and add a comment to the catalog.&lt;br&gt;Before the scanning select the necessary readable components in the config dialog, which can be mp3 tags content of some files or etc.  If you done this, you can scan one of your media with &lt;tt&gt;Add media&lt;/tt&gt;command in the Edit menu. In that dialog you have to specyfi the directory/or drive the media you want to add. It&apos;s recommended to specify the name and the number of the media which has to be unique. (The program always generate one identical name and number) You can label the media to a owner, if necessary.
&lt;br&gt;If you scanned your media, you will be able to browse in it with the browser window (like mc) , or search in it. You can save the catalog with &lt;tt&gt;save as&lt;/tt&gt; command in the Catalog menu.
&lt;br&gt;
&lt;br&gt;
&lt;i&gt;Open an existing catalog:&lt;/i&gt;Run the &lt;tt&gt;open&lt;/tt&gt; command in the Catalog menu, and choice the file of the catalog. (*.hcf)  After the opening you will be able browse the catalog or search in it.
&lt;br&gt;
&lt;/blockquote&gt;
&lt;br&gt;
&lt;b&gt;Author:&lt;/b&gt;
&lt;blockquote&gt;The program was written by  Peter Deak  (hungary)&lt;br&gt;
E-mail: hyperr@freemail.hu
&lt;br&gt;
&lt;/blockquote&gt;
&lt;br&gt;
&lt;b&gt;License:&lt;/b&gt;
&lt;blockquote&gt;General Public License (GPL)&lt;/blockquote&gt;
&lt;br&gt;
&lt;b&gt;Homepage:&lt;/b&gt;
&lt;blockquote&gt;You can read about the program and get new versions, sources etc, in the hompage of cdcat:&lt;br&gt;&lt;tt&gt;http://cdcat.sourceforge.net&lt;/tt&gt;&lt;/blockquote&gt;</source>
        <translation>&lt;p align=&quot;center&quot;&gt;&lt;font size=&quot;+1&quot;&gt;&lt;b&gt;Pomoc&lt;/b&gt;&lt;/font&gt;&lt;/p&gt;&lt;br&gt;

&lt;b&gt;Co to jest?&lt;/b&gt;&lt;br&gt;
&lt;blockquote&gt;
CdCat jest graficznym (Oparty na QT) wieloplatformowym (Linux/Windows) programem do katalogowania, który skanuje wybrane katalogi/dyski i zapisuje całość wraz z tagami mp3 oraz innymi danymi do małych plików.
Baza danych jest zapisana w gzip&apos;powanym XML&apos;u, tak żebyś zawsze mógł się nim zabawić, albo odczytać w razie potrzeby :-)
Na żądanie program może także zapisać zawartość odpowiednio małych plików. (na przykład: *.nfo)
&lt;/blockquote&gt;
&lt;br&gt;
&lt;b&gt;Użycie:&lt;/b&gt;&lt;br&gt;
&lt;blockquote&gt;
&lt;i&gt;Utwórz nowy katalog&lt;/i&gt;: Wybierz polecenie &lt;tt&gt;Nowy&lt;/tt&gt; z menu Katalog. Musisz podać nazwe nowego katalogu. Możesz podać nazwe domyślnego właściciela nośnika(który bedzie potem skanowany), oraz dodać komentarz do katalogu.&lt;br&gt;Przed rozpoczęciem skanowania, z menu konfigracji, wybierz dane które także mają być zapisywane, mogą to być tagi mp3, zawartoś określonych plików itp. Po tym, możesz rozpocząć skanowanie poleceniem &lt;tt&gt;Dodaj nośnik&lt;/tt&gt; z menu Edycji. W nowym okienku musisz wybrać katalog/dysk który chcesz dodać. Zaleca się podanie nazwy oraz numeru nośnika która muśi być unikatowa. (Program sam generuje nazwe i numer) Możesz przypisać nośnik danemu użytkownikowi w razie potrzeby. 
&lt;br&gt;Jeśli juz zeskanowałeś nośniki, możesz je przeglądać w oknie przeglądarki (tak jak w mc), albo czegoś poszukać. Możesz zapisać katalog poleceniem &lt;tt&gt;Zapisz jako&lt;/tt&gt; z menu Katalog.
&lt;br&gt;
&lt;br&gt;
&lt;i&gt;Otwórz istniejący katalog:&lt;/i&gt; Wybierz polecenie &lt;tt&gt;otwórz&lt;/tt&gt; z menu Katalog, a następnie otwórz plik z katalogiem. (*.hcf) Następnie możesz normalnie przeglądać katalog i go przeszukiwać. 
&lt;br&gt;
&lt;/blockquote&gt;
&lt;br&gt;
&lt;b&gt;Autor:&lt;/b&gt;
Program został napisany przez  Peter Deak  (Węgry)&lt;br&gt;
E-Mail: hyperr@freemail.hu
&lt;br&gt;
&lt;br&gt;Podziękowania dla mojej dziewczyny Ani, która była moim pierwszym betatesterem, i zachęcała mnie do pisani tego programu.
&lt;/blockquote&gt;
&lt;br&gt;
&lt;b&gt;Licencja:&lt;/b&gt;
&lt;blockquote&gt;eneral Public License (GPL)&lt;/blockquote&gt;
&lt;br&gt;
&lt;b&gt;Strona domowa:&lt;/b&gt;
&lt;blockquote&gt;Możesz poczytać o programie, sciągnąc nowa wersje, źródła itp. ze strony domowej CdCat&apos;a:&lt;br&gt;&lt;tt&gt;http://cdcat.sourceforge.net&lt;/tt&gt;&lt;/blockquote&gt;</translation>
    </message>
</context>
<context>
    <name>importCsv</name>
    <message>
        <source>Importing csv...</source>
        <translation type="obsolete">Importuje csv...</translation>
    </message>
    <message>
        <source>Import was successful.</source>
        <translation type="obsolete">Importowanie się powiodło.</translation>
    </message>
    <message>
        <source>1 media</source>
        <translation type="obsolete">1 nośnik</translation>
    </message>
    <message>
        <source>media</source>
        <translation type="obsolete">nośnik</translation>
    </message>
    <message>
        <source>1 directory:,
</source>
        <translation type="obsolete">1 katalog:,
</translation>
    </message>
    <message>
        <source>directories</source>
        <translation type="obsolete">katalogi</translation>
    </message>
    <message>
        <source>1 File</source>
        <translation type="obsolete">1 Plik</translation>
    </message>
    <message>
        <source>files</source>
        <translation type="obsolete">pliki</translation>
    </message>
    <message>
        <source>are imported.</source>
        <translation type="obsolete">zostało zimportowanych.</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation type="obsolete">Import sie powiódł</translation>
    </message>
    <message>
        <source>file read error</source>
        <translation type="obsolete">Błąd odczytu plik</translation>
    </message>
    <message>
        <source>Fatal error</source>
        <translation type="obsolete">Błąd krytyczny</translation>
    </message>
    <message>
        <source>Fatal error occured.</source>
        <translation type="obsolete">Nastąpił błąd krytyczny.</translation>
    </message>
    <message>
        <source>file open error</source>
        <translation type="obsolete">Błąd otwierania pliku</translation>
    </message>
    <message>
        <source>importuser</source>
        <translation type="obsolete">importuser</translation>
    </message>
    <message>
        <source>Could not read the file</source>
        <translation type="obsolete">Nie moge odczytać pliku</translation>
    </message>
    <message>
        <source>Could not open the file</source>
        <translation type="obsolete">Nie moge otworzyć pliku</translation>
    </message>
    <message>
        <source>Could not read file</source>
        <translation type="obsolete">Nie można odczytać pliku</translation>
    </message>
    <message>
        <source>Could not open file</source>
        <translation type="obsolete">Nie można otworzyć pliku</translation>
    </message>
    <message>
        <source>Importing CSV...</source>
        <translation type="obsolete">Importuje CSV...</translation>
    </message>
</context>
<context>
    <name>importGtktalogCsv</name>
    <message>
        <source>Importing CSV...</source>
        <translation>Importuje CSV...</translation>
    </message>
    <message>
        <source>Import was successful.</source>
        <translation>Importowanie się powiodło.</translation>
    </message>
    <message>
        <source>1 media</source>
        <translation>1 nośnik</translation>
    </message>
    <message>
        <source>media</source>
        <translation>nośników</translation>
    </message>
    <message>
        <source>1 directory:,
</source>
        <translation>1 katalog:,
</translation>
    </message>
    <message>
        <source>directories</source>
        <translation>katalogi</translation>
    </message>
    <message>
        <source>1 File</source>
        <translation>1 Plik</translation>
    </message>
    <message>
        <source>files</source>
        <translation>pliki</translation>
    </message>
    <message>
        <source>are imported.</source>
        <translation>zostało zimportowanych.</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>Importowanie sie powiódło</translation>
    </message>
    <message>
        <source>file read error</source>
        <translation>Błąd odczytu plik</translation>
    </message>
    <message>
        <source>Could not read file</source>
        <translation>Nie można odczytać pliku</translation>
    </message>
    <message>
        <source>Fatal error</source>
        <translation>Błąd krytyczny</translation>
    </message>
    <message>
        <source>Fatal error occured.</source>
        <translation>Nastąpił błąd krytyczny.</translation>
    </message>
    <message>
        <source>file open error</source>
        <translation>Błąd otwierania pliku</translation>
    </message>
    <message>
        <source>Could not open file</source>
        <translation>Nie można otworzyć pliku</translation>
    </message>
    <message>
        <source>importuser</source>
        <translation>importuser</translation>
    </message>
</context>
<context>
    <name>importGtktalogXml</name>
    <message>
        <source>Importing XML...</source>
        <translation>Importuje XML...</translation>
    </message>
    <message>
        <source>XML import was successful.</source>
        <translation>Import XML zakończony sukcesem.</translation>
    </message>
    <message>
        <source>1 media</source>
        <translation>1 nośnik</translation>
    </message>
    <message>
        <source>media</source>
        <translation>nośników</translation>
    </message>
    <message>
        <source>1 directory:,
</source>
        <translation>1 katalog:,
</translation>
    </message>
    <message>
        <source>directories</source>
        <translation>katalogów</translation>
    </message>
    <message>
        <source>1 File</source>
        <translation>1 Plik</translation>
    </message>
    <message>
        <source>files</source>
        <translation>plików</translation>
    </message>
    <message>
        <source>are imported.</source>
        <translation>zostało zimportowanych.</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>Importowanie sie powiódło</translation>
    </message>
    <message>
        <source>parse error</source>
        <translation>błąd parsowania</translation>
    </message>
    <message>
        <source>error during parsing</source>
        <translation>błąd podczas parsowania</translation>
    </message>
    <message>
        <source>importuser</source>
        <translation>importuser</translation>
    </message>
</context>
<context>
    <name>importWhereIsItXml</name>
    <message>
        <source>Importing XML...</source>
        <translation>Importuje XML...</translation>
    </message>
    <message>
        <source>Importing XML from WhereIsIt was successful.</source>
        <translation>Import XML&apos;a z WhereIsIt&apos;a powódł się.</translation>
    </message>
    <message>
        <source>1 media</source>
        <translation>1 nośnik</translation>
    </message>
    <message>
        <source>media</source>
        <translation>nośników</translation>
    </message>
    <message>
        <source>1 directory:,
</source>
        <translation>1 katalog:,
</translation>
    </message>
    <message>
        <source>directories</source>
        <translation>katalogów</translation>
    </message>
    <message>
        <source>1 File</source>
        <translation>1 Plik</translation>
    </message>
    <message>
        <source>files</source>
        <translation>plików</translation>
    </message>
    <message>
        <source>are imported.</source>
        <translation>zostało zimportowanych.</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation>Import sie powiódł</translation>
    </message>
    <message>
        <source>parse error</source>
        <translation>błąd parsowania</translation>
    </message>
    <message>
        <source>error during parsing</source>
        <translation>błąd podczas parsowania</translation>
    </message>
</context>
<context>
    <name>importXml</name>
    <message>
        <source>Importing XML...</source>
        <translation type="obsolete">Importuje XML...</translation>
    </message>
    <message>
        <source>XML import was successful.</source>
        <translation type="obsolete">Import XML zakończony sukcesem.</translation>
    </message>
    <message>
        <source>1 media</source>
        <translation type="obsolete">1 nośnik</translation>
    </message>
    <message>
        <source>media</source>
        <translation type="obsolete">nośniki</translation>
    </message>
    <message>
        <source>1 directory:,
</source>
        <translation type="obsolete">1 katalog:,
</translation>
    </message>
    <message>
        <source>directories</source>
        <translation type="obsolete">katalogi</translation>
    </message>
    <message>
        <source>1 File</source>
        <translation type="obsolete">1 Plik</translation>
    </message>
    <message>
        <source>files</source>
        <translation type="obsolete">plików</translation>
    </message>
    <message>
        <source>are imported.</source>
        <translation type="obsolete">zostało zimportowanych.</translation>
    </message>
    <message>
        <source>Import successful</source>
        <translation type="obsolete">Import sie powiódł</translation>
    </message>
    <message>
        <source>parse error</source>
        <translation type="obsolete">błąd parsowania</translation>
    </message>
    <message>
        <source>error during parsing</source>
        <translation type="obsolete">błąd podczas parsowania</translation>
    </message>
    <message>
        <source>importuser</source>
        <translation type="obsolete">importuser</translation>
    </message>
</context>
<context>
    <name>newdbdialog</name>
    <message>
        <source>DataBase&apos;s Properties</source>
        <translation>Właściwości bazy danych</translation>
    </message>
    <message>
        <source>DataBase Name:</source>
        <translation>Nazwa bazy danych:</translation>
    </message>
    <message>
        <source>DataBase Owner:</source>
        <translation>Właściciel bazy danych:</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Komentarz:</translation>
    </message>
    <message>
        <source>Catalog</source>
        <translation>Spis</translation>
    </message>
    <message>
        <source>hcat-user</source>
        <translation>hcat-user</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source></source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>renamedialog</name>
    <message>
        <source>Rename node...</source>
        <translation>Zmien nazwe wpisu...</translation>
    </message>
    <message>
        <source>Give the new name:</source>
        <translation>Podaj nową nazwe:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Error:</source>
        <translation>Błąd:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>The new (media)name must be unique!</source>
        <translation type="obsolete">Nowa nazwa (nośnika) musi być unikatowa!</translation>
    </message>
    <message>
        <source>The new (media) name must be unique!</source>
        <translation>Nowa nazwa (nośnika) musi być unikatowa!</translation>
    </message>
    <message>
        <source>The new media name can&apos;t starts with &quot;@&quot; !</source>
        <translation>Nowa nazwa nośnika nie może zaczynać się od znaku &quot;@&quot;!</translation>
    </message>
</context>
<context>
    <name>renumberdialog</name>
    <message>
        <source>Error:</source>
        <translation>Błąd:</translation>
    </message>
    <message>
        <source>The element is NOT a Media!</source>
        <translation>Ten element to nie Nośnik!</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Re-Number media...</source>
        <translation>Zmień numer nosnika...</translation>
    </message>
    <message>
        <source>Give the new serial number:</source>
        <translation>Podaj nowy numer:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>I Cannot understand the text as number!</source>
        <translation type="obsolete">Nie rozpoznaje w tym liczby!</translation>
    </message>
    <message>
        <source>The new media-number must be unique!</source>
        <translation>Nowy numer nośnika musi być unikatowa!</translation>
    </message>
    <message>
        <source>Please enter number value!</source>
        <translation>Prosze wprowadzic wartość liczbową!</translation>
    </message>
</context>
<context>
    <name>seekEngine</name>
    <message>
        <source>Error in the pattern:</source>
        <translation>Błąd w wyrażeniu:</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>There is no matching.</source>
        <translation>Nic nie znaleziono.</translation>
    </message>
    <message>
        <source>dir</source>
        <translation>katalog</translation>
    </message>
    <message>
        <source>file</source>
        <translation>plik</translation>
    </message>
    <message>
        <source>error</source>
        <translation>błąd</translation>
    </message>
    <message>
        <source>media</source>
        <translation>Nośnik</translation>
    </message>
</context>
</TS>
